DestinyActivityDifficultyId enum

Inheritance
Available extensions

Values

Trivial → const DestinyActivityDifficultyId

Trivial = 0

Easy → const DestinyActivityDifficultyId

Easy = 1

Normal → const DestinyActivityDifficultyId

Normal = 2

Challenging → const DestinyActivityDifficultyId

Challenging = 3

Hard → const DestinyActivityDifficultyId

Hard = 4

Brave → const DestinyActivityDifficultyId

Brave = 5

AlmostImpossible → const DestinyActivityDifficultyId

AlmostImpossible = 6

Impossible → const DestinyActivityDifficultyId

Impossible = 7

Count → const DestinyActivityDifficultyId

Count = 8

ProtectedInvalidEnumValue → const DestinyActivityDifficultyId

value not found fallback

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int?

Available on DestinyActivityDifficultyId, provided by the DestinyActivityDifficultyIdExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DestinyActivityDifficultyId>
A constant List of the values in this enum, in order of their declaration.