DestinyPresentationDisplayStyle enum
- Inheritance
- Available extensions
Values
- Category → const DestinyPresentationDisplayStyle
-
Category = 0 Display the item as a category, through which sub-items are filtered.
- Badge → const DestinyPresentationDisplayStyle
-
Badge = 1
- Medals → const DestinyPresentationDisplayStyle
-
Medals = 2
- Collectible → const DestinyPresentationDisplayStyle
-
Collectible = 3
- Record → const DestinyPresentationDisplayStyle
-
Record = 4
- SeasonalTriumph → const DestinyPresentationDisplayStyle
-
SeasonalTriumph = 5
- GuardianRank → const DestinyPresentationDisplayStyle
-
GuardianRank = 6
- CategoryCollectibles → const DestinyPresentationDisplayStyle
-
CategoryCollectibles = 7
- CategoryCurrencies → const DestinyPresentationDisplayStyle
-
CategoryCurrencies = 8
- CategoryEmblems → const DestinyPresentationDisplayStyle
-
CategoryEmblems = 9
- CategoryEmotes → const DestinyPresentationDisplayStyle
-
CategoryEmotes = 10
- CategoryEngrams → const DestinyPresentationDisplayStyle
-
CategoryEngrams = 11
- CategoryFinishers → const DestinyPresentationDisplayStyle
-
CategoryFinishers = 12
- CategoryGhosts → const DestinyPresentationDisplayStyle
-
CategoryGhosts = 13
- CategoryMisc → const DestinyPresentationDisplayStyle
-
CategoryMisc = 14
- CategoryMods → const DestinyPresentationDisplayStyle
-
CategoryMods = 15
- CategoryOrnaments → const DestinyPresentationDisplayStyle
-
CategoryOrnaments = 16
- CategoryShaders → const DestinyPresentationDisplayStyle
-
CategoryShaders = 17
- CategoryShips → const DestinyPresentationDisplayStyle
-
CategoryShips = 18
- CategorySpawnfx → const DestinyPresentationDisplayStyle
-
CategorySpawnfx = 19
- CategoryUpgradeMaterials → const DestinyPresentationDisplayStyle
-
CategoryUpgradeMaterials = 20
- ProtectedInvalidEnumValue → const DestinyPresentationDisplayStyle
-
value not found fallback
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int?
-
Available on DestinyPresentationDisplayStyle, provided by the DestinyPresentationDisplayStyleExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DestinyPresentationDisplayStyle> - A constant List of the values in this enum, in order of their declaration.