FireteamFinderOptionDisplayFormat enum
- Inheritance
- Available extensions
Values
- Text → const FireteamFinderOptionDisplayFormat
-
Text = 0
- Integer → const FireteamFinderOptionDisplayFormat
-
Integer = 1
- Bool → const FireteamFinderOptionDisplayFormat
-
Bool = 2
- FormatString → const FireteamFinderOptionDisplayFormat
-
FormatString = 3
- ProtectedInvalidEnumValue → const FireteamFinderOptionDisplayFormat
-
value not found fallback
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int?
-
Available on FireteamFinderOptionDisplayFormat, provided by the FireteamFinderOptionDisplayFormatExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FireteamFinderOptionDisplayFormat> - A constant List of the values in this enum, in order of their declaration.