FireteamFinderOptionValueFlags class

Constructors

FireteamFinderOptionValueFlags(int _value)
const
FireteamFinderOptionValueFlags.fromJson(int numValue)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
no setter

Methods

contains(FireteamFinderOptionValueFlags childValue) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() int
toString() String
A string representation of this object.
inherited

Operators

operator &(FireteamFinderOptionValueFlags item) int
operator ==(Object other) bool
The equality operator.
override

Constants

CreateListingDefaultValue → const FireteamFinderOptionValueFlags
CreateListingDefaultValue = 1
None → const FireteamFinderOptionValueFlags
None = 0
SearchFilterDefaultValue → const FireteamFinderOptionValueFlags
SearchFilterDefaultValue = 2