Enhanced constant
ItemState
const Enhanced
Enhanced = 32 If this bit is set, the item has been 'enhanced' by the player.
Implementation
static const ItemState Enhanced = ItemState(32);
Enhanced = 32 If this bit is set, the item has been 'enhanced' by the player.
static const ItemState Enhanced = ItemState(32);