DestinyActivityDifficultyTierDefinition class

Annotations
  • @JsonSerializable.new()

Properties

activityLevel int?
getter/setter pair
displayProperties DestinyDisplayPropertiesDefinition?
Many Destiny*Definition contracts - the "first order" entities of Destiny that have their own tables in the Manifest Database - also have displayable information. This is the base class for that display information.
getter/setter pair
fixedActivitySkulls List<DestinyActivitySkull>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maximumFireteamLeaderPower int?
getter/setter pair
minimumFireteamLeaderPower int?
getter/setter pair
optionalRequiredTrait int?
getter/setter pair
recommendedActivityLevelOffset int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scoreTimeLimitMultiplier int?
getter/setter pair
selectableSkullCollectionHashes List<int>?
getter/setter pair
skullSubcategoryOverrides List<DestinyActivityDifficultyTierSubcategoryOverride>?
getter/setter pair
tierRank int?
getter/setter pair
tierType DestinyActivityDifficultyTierType?
getter/setter pair

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited