DestinyActivityDurationEstimate class

Annotations
  • @JsonSerializable.new()

Properties

durationEstimateText String?
The text string showing the estimated time to complete this activity
getter/setter pair
durationPipsFilledCount int?
The number of filled pips shown on the Portal tile
getter/setter pair
durationPipsTotalCount int?
The total number of pips shown on the Portal tile
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asyncFromJson(Map<String, dynamic> json) Future<DestinyActivityDurationEstimate>