linkedGraphs property
- @JsonKey.new(name: 'linkedGraphs')
getter/setter pair
Represents links between this Activity Graph and other ones.
Implementation
@JsonKey(name:'linkedGraphs')
List<DestinyLinkedGraphDefinition>? linkedGraphs;
Represents links between this Activity Graph and other ones.
@JsonKey(name:'linkedGraphs')
List<DestinyLinkedGraphDefinition>? linkedGraphs;