models/destiny_activity_interactable_definition library

Classes

DestinyActivityInteractableDefinition
There are times in every Activity's life when interacting with an object in the world will result in another Activity activating. Well, not every Activity. Just certain ones. Anyways, this defines a set of interactable components, the activities that they spawn when you interact with them, and the conditions under which they can be interacted with. Sadly, we don't get any really good data for them, like positional data... yet. I have hopes for future data that we could put on this.