DestinyActivityInteractableDefinition class

There are times in every Activity's life when interacting with an object in the world will result in another Activity activating. Well, not every Activity. Just certain ones. Anyways, this defines a set of interactable components, the activities that they spawn when you interact with them, and the conditions under which they can be interacted with. Sadly, we don't get any really good data for them, like positional data... yet. I have hopes for future data that we could put on this.

Annotations
  • @JsonSerializable.new()

Properties

entries List<DestinyActivityInteractableEntryDefinition>?
The possible interactables in this activity interactable definition.
getter/setter pair
hash int?
The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
index int?
The index of the entity as it was found in the investment tables.
getter/setter pair
redacted bool?
If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited