failedRequirementIndexes property
- @JsonKey.new(name: 'failedRequirementIndexes')
getter/setter pair
If the requirements are not met for crafting this item, these will index into the list of failure strings.
Implementation
@JsonKey(name:'failedRequirementIndexes')
List<int>? failedRequirementIndexes;