craftables property
- @JsonKey.new(name: 'craftables')
getter/setter pair
A map of craftable item hashes to craftable item state components.
Implementation
@JsonKey(name:'craftables')
Map<String, DestinyCraftableComponent>? craftables;
A map of craftable item hashes to craftable item state components.
@JsonKey(name:'craftables')
Map<String, DestinyCraftableComponent>? craftables;