DestinyEquipableItemSetDefinition class

Perks that are active only when you have a certain number of set items equipped.

Annotations
  • @JsonSerializable.new()

Properties

displayProperties DestinyDisplayPropertiesDefinition?
Display Properties, including name and icon, for this item set
getter/setter pair
hash int?
The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
index int?
The index of the entity as it was found in the investment tables.
getter/setter pair
redacted bool?
If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setItems List<int>?
The items that confer these perks.
getter/setter pair
setPerks List<DestinyItemSetPerkDefinition>?
The perks conferred by this set of armor pieces.
getter/setter pair

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asyncFromJson(Map<String, dynamic> json) Future<DestinyEquipableItemSetDefinition>