DestinyFireteamFinderActivityGraphDefinition class

Annotations
  • @JsonSerializable.new()

Properties

activityTreeChildSortMode DestinyActivityTreeChildSortMode?
getter/setter pair
children List<int>?
getter/setter pair
color DestinyColor?
Represents a color whose RGBA values are all represented as values between 0 and 255.
getter/setter pair
displayProperties DestinyDisplayPropertiesDefinition?
Many Destiny*Definition contracts - the "first order" entities of Destiny that have their own tables in the Manifest Database - also have displayable information. This is the base class for that display information.
getter/setter pair
enabledOnTreeTypesListEnum List<DestinyActivityTreeType>?
getter/setter pair
hash int?
The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
index int?
The index of the entity as it was found in the investment tables.
getter/setter pair
isPlayerElectedDifficultyNode bool?
getter/setter pair
parentHash int?
getter/setter pair
redacted bool?
If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!
getter/setter pair
relatedActivityHashes List<int>?
getter/setter pair
relatedActivitySetHashes List<int>?
getter/setter pair
relatedDirectorNodes List<DestinyActivityGraphReference>?
getter/setter pair
relatedInteractableActivities List<DestinyActivityInteractableReference>?
getter/setter pair
relatedLocationHashes List<int>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfAndAllDescendantHashes List<int>?
getter/setter pair
sortMatchmadeActivitiesToFront bool?
getter/setter pair
sortPriority int?
getter/setter pair
specificActivitySetHash int?
getter/setter pair

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited