DestinyFireteamFinderOptionValues class

Annotations
  • @JsonSerializable.new()

Properties

displayFormatType FireteamFinderOptionDisplayFormat?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
optionalFormatString String?
getter/setter pair
optionalNull DestinyDisplayPropertiesDefinition?
Many Destiny*Definition contracts - the "first order" entities of Destiny that have their own tables in the Manifest Database - also have displayable information. This is the base class for that display information.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type FireteamFinderOptionValueProviderType?
getter/setter pair
valueDefinitions List<DestinyFireteamFinderOptionValueDefinition>?
getter/setter pair

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asyncFromJson(Map<String, dynamic> json) Future<DestinyFireteamFinderOptionValues>