optionalNull property
- @JsonKey.new(name: 'optionalNull')
getter/setter pair
Many Destiny*Definition contracts - the "first order" entities of Destiny that have their own tables in the Manifest Database - also have displayable information. This is the base class for that display information.
Implementation
@JsonKey(name:'optionalNull')
DestinyDisplayPropertiesDefinition? optionalNull;