DestinyIconDefinition class

Lists of icons that can be used for a variety of purposes

Annotations
  • @JsonSerializable.new()

Constructors

DestinyIconDefinition()
DestinyIconDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

background String?
getter/setter pair
foreground String?
getter/setter pair
hash int?
The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
highResForeground String?
getter/setter pair
index int?
The index of the entity as it was found in the investment tables.
getter/setter pair
redacted bool?
If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryBackground String?
getter/setter pair
specialBackground String?
getter/setter pair

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asyncFromJson(Map<String, dynamic> json) Future<DestinyIconDefinition>