stackSize property
If available, this is the stack size to display for the socket plug item.
Implementation
@JsonKey(name:'stackSize')
int? stackSize;
If available, this is the stack size to display for the socket plug item.
@JsonKey(name:'stackSize')
int? stackSize;