maxStackSize property
If available, this is the maximum stack size to display for the socket plug item.
Implementation
@JsonKey(name:'maxStackSize')
int? maxStackSize;
If available, this is the maximum stack size to display for the socket plug item.
@JsonKey(name:'maxStackSize')
int? maxStackSize;