DestinyItemSetPerkDefinition class

Annotations
  • @JsonSerializable.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
requiredSetCount int?
The number of set pieces required to activate the perk.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sandboxPerkHash int?
The perk this set confers.
getter/setter pair

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asyncFromJson(Map<String, dynamic> json) Future<DestinyItemSetPerkDefinition>