requiredSetCount property
The number of set pieces required to activate the perk.
Implementation
@JsonKey(name:'requiredSetCount')
int? requiredSetCount;
The number of set pieces required to activate the perk.
@JsonKey(name:'requiredSetCount')
int? requiredSetCount;