DestinyLinkedGraphDefinition class

This describes links between the current graph and others, as well as when that link is relevant.

Annotations
  • @JsonSerializable.new()

Properties

description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
linkedGraphId int?
getter/setter pair
linkedGraphs List<DestinyLinkedGraphEntryDefinition>?
getter/setter pair
name String?
getter/setter pair
overview String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asyncFromJson(Map<String, dynamic> json) Future<DestinyLinkedGraphDefinition>