completionValue property

  1. @JsonKey.new(name: 'completionValue')
int? completionValue
getter/setter pair

The value that the unlock value defined in unlockValueHash must reach in order for the objective to be considered Completed. Used in calculating progress and completion status.

Implementation

@JsonKey(name:'completionValue')
int? completionValue;