perks property
If this objective enables Perks intrinsically, the conditions for that enabling are defined here.
Implementation
@JsonKey(name:'perks')
DestinyObjectivePerkEntryDefinition? perks;
If this objective enables Perks intrinsically, the conditions for that enabling are defined here.
@JsonKey(name:'perks')
DestinyObjectivePerkEntryDefinition? perks;