isSeasonal property

  1. @JsonKey.new(name: 'isSeasonal')
bool? isSeasonal
getter/setter pair

Primarily for Guardian Ranks, this property if the contents of this node are tied to the current season. These nodes are shown with a different color for the in-game Guardian Ranks display.

Implementation

@JsonKey(name:'isSeasonal')
bool? isSeasonal;