currentSeasonPassHash property
If populated, this is a reference to the season pass that is currently active.
Implementation
@JsonKey(name:'currentSeasonPassHash')
int? currentSeasonPassHash;
If populated, this is a reference to the season pass that is currently active.
@JsonKey(name:'currentSeasonPassHash')
int? currentSeasonPassHash;