renewedGuardianRank property
The seasonal 'renewed' Guardian Rank value. This rank value resets at the start of each new season to the highest-earned non-advanced rank.
Implementation
@JsonKey(name:'renewedGuardianRank')
int? renewedGuardianRank;
The seasonal 'renewed' Guardian Rank value. This rank value resets at the start of each new season to the highest-earned non-advanced rank.
@JsonKey(name:'renewedGuardianRank')
int? renewedGuardianRank;