GroupEditHistory class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GroupEditHistory()
-
GroupEditHistory.fromJson(Map<
String, dynamic> json) -
factory
Properties
- about ↔ String?
-
getter/setter pair
- aboutEditors ↔ String?
-
getter/setter pair
- clanCallsign ↔ String?
-
getter/setter pair
- clanCallsignEditors ↔ String?
-
getter/setter pair
- editDate ↔ String?
-
getter/setter pair
-
groupEditors
↔ List<
UserInfoCard> ? -
getter/setter pair
- groupId ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- motto ↔ String?
-
getter/setter pair
- mottoEditors ↔ String?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- nameEditors ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asyncToJson(
) → Future< Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
asyncFromJson(
Map< String, dynamic> json) → Future<GroupEditHistory>