SchemaRecordStateBlock class

Annotations
  • @JsonSerializable.new()

Constructors

SchemaRecordStateBlock()
SchemaRecordStateBlock.fromJson(Map<String, dynamic> json)
factory

Properties

featuredPriority int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
obscuredDescription String?
A display description override to show when this record is 'obscured' instead of the default obscured display description.
getter/setter pair
obscuredName String?
A display name override to show when this record is 'obscured' instead of the default obscured display name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asyncToJson() Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asyncFromJson(Map<String, dynamic> json) Future<SchemaRecordStateBlock>