destinyMemberships property
- @JsonKey.new(name: 'destinyMemberships')
getter/setter pair
this allows you to see destiny memberships that are visible and linked to this account (regardless of whether or not they have characters on the world server)
Implementation
@JsonKey(name:'destinyMemberships')
List<GroupUserInfoCard>? destinyMemberships;