marathonMembershipId property

  1. @JsonKey.new(name: 'marathonMembershipId')
String? marathonMembershipId
getter/setter pair

If this property is populated, it will have the membershipId for the Marathon Membership on this user's account If null, this user has no Marathon (i.e. "GoliathGame") membership.

Implementation

@JsonKey(name:'marathonMembershipId')
String? marathonMembershipId;