DestinyActivityModifierConnotation enum
- Inheritance
- Available extensions
Values
- Neutral → const DestinyActivityModifierConnotation
-
Neutral = 0
- Positive → const DestinyActivityModifierConnotation
-
Positive = 1
- Negative → const DestinyActivityModifierConnotation
-
Negative = 2
- Affix → const DestinyActivityModifierConnotation
-
Affix = 3
- Informational → const DestinyActivityModifierConnotation
-
Informational = 4
- Reward → const DestinyActivityModifierConnotation
-
Reward = 5
- Event → const DestinyActivityModifierConnotation
-
Event = 6
- Count → const DestinyActivityModifierConnotation
-
Count = 7
- ProtectedInvalidEnumValue → const DestinyActivityModifierConnotation
-
value not found fallback
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int?
-
Available on DestinyActivityModifierConnotation, provided by the DestinyActivityModifierConnotationExtension extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DestinyActivityModifierConnotation> - A constant List of the values in this enum, in order of their declaration.