DestinyActivitySkull class
- Annotations
-
- @JsonSerializable.new()
Constructors
- DestinyActivitySkull()
-
DestinyActivitySkull.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activityModifierConnotation ↔ DestinyActivityModifierConnotation?
-
getter/setter pair
- activityModifierDisplayCategory ↔ DestinyActivityModifierDisplayCategory?
-
getter/setter pair
-
getter/setter pair
- displayInActivitySelection ↔ bool?
-
getter/setter pair
-
getter/setter pair
- displayProperties ↔ DestinyDisplayPropertiesDefinition?
-
Many Destiny*Definition contracts - the "first order" entities of Destiny that have their own tables in the Manifest Database - also have displayable information. This is the base class for that display information.
getter/setter pair
- dynamicUse ↔ DestinyActivitySkullDynamicUse?
-
getter/setter pair
- hash ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasUi ↔ bool?
-
getter/setter pair
- modifierMultiplierContribution ↔ double?
-
getter/setter pair
- modifierPowerContribution ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skullExclusionGroupHash ↔ int?
-
getter/setter pair
- skullIdentifierHash ↔ int?
-
getter/setter pair
-
skullOptions
↔ List<
DestinyActivitySkullOption> ? -
getter/setter pair
Methods
-
asyncToJson(
) → Future< Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
asyncFromJson(
Map< String, dynamic> json) → Future<DestinyActivitySkull>