hasVirtualStackSize property
If true, this material requirement references a virtual item stack size value. You can get that value from a corresponding DestinyMaterialRequirementSetState.
Implementation
@JsonKey(name:'hasVirtualStackSize')
bool? hasVirtualStackSize;