allowOvercompletion property
If True, the progress will continue even beyond the point where the objective met its minimum completion requirements. Your UI will have to accommodate it.
Implementation
@JsonKey(name:'allowOvercompletion')
bool? allowOvercompletion;