completionValue property
The value that the unlock value defined in unlockValueHash must reach in order for the objective to be considered Completed. Used in calculating progress and completion status.
Implementation
@JsonKey(name:'completionValue')
int? completionValue;