marathonMembershipId property
If this property is populated, it will have the membershipId for the Marathon Membership on this user's account If null, this user has no Marathon (i.e. "GoliathGame") membership.
Implementation
@JsonKey(name:'marathonMembershipId')
String? marathonMembershipId;